@@ -8,13 +8,15 @@ class ElastalertWebhook(WebhookBase):
     def incoming(self, query_string, payload):
 
         try:
-            # Default parameters
+            #for any missing key in payload, default value set to 'N/A'
+            print("using alerta-elastalert version: 0.0.14")
             print("payload: "+str(payload))
             rawData = "data="+str(payload)
             resource = payload.get('queryKey','N/A')
             environment = payload.get('fedUniqueName','N/A')
             res = payload.get('event','N/A')
             group = payload.get('group','N/A')
+            #if event key present in payload, retrieve other nested key values
             if(res!="N/A"):
                 event = res.get('eventName','N/A')
                 severity =res.get('severity','N/A').lower()
@@ -26,12 +28,12 @@ class ElastalertWebhook(WebhookBase):
             tags = []
             attributes = {}
             attributes['potentialImpact']=payload.get('potentialImpact','N/A')
-            attributes['remedy']=payload.get('remedy','N/A')
-            attributes['payload']=str(payload)
-            attributes['timestampReceived']=payload.get('@timestamp','N/A')
+            attributes['repairAction']=payload.get('repairAction','N/A')
+            #parse @timestamp key field from string to datetime
             try:
                 createTime = parse_date(payload.get('@timestamp'))
             except Exception as e:
+            #if unable to parse or the key is missing, createTime will pick current UTC time
                 print("unable to parse @timestamp as createTime")
                 createTime = 'N/A'
             try:
@@ -39,6 +41,8 @@ class ElastalertWebhook(WebhookBase):
             except Exception as e:
                 print("origin not defined")
                 origin = 'N/A'
+            #logging values after being parsed
+            print("Values being mapped: resource="+resource+",environment="+environment+",group="+group+",event="+event+",severity="+severity+",text="+text+",atributes="+str(attributes)+",createTime="+str(createTime)+",origin="+origin);
         except Exception as e:
             print("Error reading payload: "+str(e)) 
 
@@ -51,35 +55,9 @@ class ElastalertWebhook(WebhookBase):
             text = text,
             tags = tags,
             origin = origin,
-            createTime = createTime,
+            create_time = createTime,
             attributes = attributes,
             environment = environment,
-            type = "ElastAlertNotification",
-            raw_data = "This is test",
-            rawData = "Second Test"
-        #     environment=payload.get('environment', environment),
-        #     severity=payload.get('severity', severity),
-        #     service=['fail2ban'],
-        #     group=payload.get('group', group),
-        #     value='BAN',
-        #     text=payload.get('message', text),
-        #     tags=payload.get('tags', tags),
-        #     attributes=payload.get('attributes', attributes),
-        #     origin=payload.get('hostname', origin),
-        #     raw_data=json.dumps(payload, indent=4)
+            event_type="ElastAlertNotification",
+            raw_data = json.dumps(payload)
         )
-
-        # return Alert(
-        #     resource=payload['resource'],
-        #     event=payload['event'],
-        #     environment=payload.get('environment', environment),
-        #     severity=payload.get('severity', severity),
-        #     service=['fail2ban'],
-        #     group=payload.get('group', group),
-        #     value='BAN',
-        #     text=payload.get('message', text),
-        #     tags=payload.get('tags', tags),
-        #     attributes=payload.get('attributes', attributes),
-        #     origin=payload.get('hostname', origin),
-        #     raw_data=json.dumps(payload, indent=4)
-        # )   
